@@ -458,18 +458,18 @@ Glib::ustring App_Glom::ui_file_select_save(const Glib::ustring& old_file_uri) /
   //Reimplement this whole function, just so we can use our custom FileChooserDialog class:
   App& app = *this;
 
-  Gtk::FileChooserDialog* fileChooser_Save = 0;
+  std::auto_ptr<Gtk::FileChooserDialog> fileChooser_Save;
   Glom::FileChooserDialog* fileChooser_SaveExtras = 0;
 
   //Create the appropriate dialog, depending on how the caller set m_ui_save_extra_showextras:
   if(m_ui_save_extra_showextras)
   {
     fileChooser_SaveExtras = new Glom::FileChooserDialog(gettext("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
-    fileChooser_Save = fileChooser_SaveExtras;
+    fileChooser_Save.reset(fileChooser_SaveExtras);
   }
   else
   {
-    fileChooser_Save = new Gtk::FileChooserDialog(gettext("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
+    fileChooser_Save.reset(new Gtk::FileChooserDialog(gettext("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE));
   }
 
 
@@ -713,6 +713,12 @@ bool App_Glom::on_document_load()
       const bool is_example = pDocument->get_is_example_file();
       if(pDocument->get_is_example_file())
       {
+        // Remember the URI to the example file to be able to prevent
+        // adding the URI to the recently used files in document_history_add.
+        // We want to add the document that is created from the example
+        // instead of the example itself.
+        m_example_uri = pDocument->get_file_uri();
+
         pDocument->set_file_uri(Glib::ustring()); //Prevent it from defaulting to the read-only examples directory when offering saveas.
 
         //m_ui_save_extra_* are used by offer_saveas() if it's not empty:
@@ -722,6 +728,8 @@ bool App_Glom::on_document_load()
         m_ui_save_extra_newdb_title = "TODO";
         m_ui_save_extra_newdb_selfhosted = true;
         offer_saveas();
+        // Note that bakery will try to add the example file itself to the
+        // recently used documents, which is not what we want.
         m_ui_save_extra_message.clear();
         m_ui_save_extra_title.clear();
 
@@ -928,13 +936,35 @@ bool App_Glom::offer_new_or_existing()
   refXml->get_widget("dialog_existing_or_new", dialog);
   dialog->set_transient_for(*this);
 
-  int response_id = dialog->run();
+  Gtk::RecentChooserWidget* recent_chooser = NULL;
+  refXml->get_widget("existing_or_new_recentchooser", recent_chooser);
+
+  Gtk::RecentFilter filter;
+  filter.add_mime_type("application/x-glom");
+  recent_chooser->set_filter(filter);
+
+  /* Don't show files that don't exist anymore: */
+  recent_chooser->set_show_not_found(FALSE);
+
+  // Hide the recent chooser when they are not any recently used files
+  Gtk::Frame* recent_frame = NULL;
+  refXml->get_widget("existing_or_new_recentchooser_frame", recent_frame);
+  if(recent_chooser->get_items().empty()) recent_frame->hide();
+
+  recent_chooser->signal_item_activated().connect(sigc::bind(sigc::mem_fun(*dialog, &Gtk::Dialog::response), 1)); // Open
+
+  const int response_id = dialog->run();
+  Glib::ustring selected_uri = recent_chooser->get_current_uri();
   delete dialog;
   dialog = 0;
 
   if(response_id == 1) //Open
   {
-    on_menu_file_open();
+    // When a recent document was selected, open that one instead.
+    if(selected_uri.empty())
+      on_menu_file_open();
+    else
+      open_document(selected_uri);
 
     //Check that a document was opened:
     Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
@@ -1592,6 +1622,21 @@ App_Glom* App_Glom::get_application()
   return global_application;
 }
 
+void App_Glom::document_history_add(const Glib::ustring& file_uri)
+{
+  // We override this so we can prevent example files from being saved in the recently-used list:
+
+  bool prevent = false;
+  if(!file_uri.empty())
+  {
+    prevent = (file_uri == m_example_uri);
+  }
+
+  // Call the base class:
+  if(!prevent)
+    Bakery::App_WithDoc_Gtk::document_history_add(file_uri);
+}
+
 } //namespace Glom
 
 
