@@ -154,6 +154,16 @@ sharedptr<SharedConnection> Base_DB::connect_to_server(Gtk::Window* parent_windo
   return ConnectionPool::get_and_connect();
 }
 
+void Base_DB::handle_error(const Glib::Exception& ex)
+{
+  std::cerr << "Internal Error (Base_DB::handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
+
+  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
+  dialog.set_secondary_text(ex.what());
+  //TODO: dialog.set_transient_for(*get_application());
+  dialog.run();
+}
+
 void Base_DB::handle_error(const std::exception& ex)
 {
   std::cerr << "Internal Error (Base_DB::handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
@@ -654,6 +664,11 @@ bool Base_DB::add_standard_tables() const
       return false;
     }
   }
+  catch(const Glib::Exception& ex)
+  {
+    std::cerr << "Base_DB::add_standard_tables(): caught exception: " << ex.what() << std::endl;
+    return false;
+  }
   catch(const std::exception& ex)
   {
     std::cerr << "Base_DB::add_standard_tables(): caught exception: " << ex.what() << std::endl;
@@ -870,6 +885,10 @@ SystemPrefs Base_DB::get_database_preferences() const
 
     }
   }
+  catch(const Glib::Exception& ex)
+  {
+    std::cerr << "Base_DB::get_database_preferences(): exception: " << ex.what() << std::endl;
+  }
   catch(const std::exception& ex)
   {
     std::cerr << "Base_DB::get_database_preferences(): exception: " << ex.what() << std::endl;
@@ -909,6 +928,10 @@ void Base_DB::set_database_preferences(const SystemPrefs& prefs)
     {
       Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute(sql_query);
     }
+    catch(const Glib::Exception& ex)
+    {
+      std::cerr << "Base_DB::set_database_preferences(): exception: " << ex.what() << std::endl;
+    }
     catch(const std::exception& ex)
     {
       std::cerr << "Base_DB::set_database_preferences(): exception: " << ex.what() << std::endl;
@@ -1949,6 +1972,11 @@ bool Base_DB::set_field_value_in_database(const LayoutFieldInRecord& layoutfield
         return false; //failed.
       }
     }
+    catch(const Glib::Exception& ex)
+    {
+      handle_error(ex);
+      return false;
+    }
     catch(const std::exception& ex)
     {
       handle_error(ex);
