@@ -24,6 +24,9 @@
 //#include <libgnome/gnome-i18n.h>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Dialog_Properties(cobject, refGlade),
   m_pDataWidget_DefaultValueSimple(0),
@@ -41,13 +44,17 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
 
   refGlade->get_widget("hbox_default_value_simple",  m_pBox_DefaultValueSimple);
 
-  refGlade->get_widget("box_default_value",  m_pBox_DefaultValue);
+  refGlade->get_widget("box_default_value",  m_pBox_ValueTab);
+
+  refGlade->get_widget("radiobutton_userentry",  m_pRadio_UserEntry);
+  refGlade->get_widget("alignment_userentry",  m_pAlignment_UserEntry);
+
   refGlade->get_widget("checkbutton_lookup",  m_pCheck_Lookup);
   refGlade->get_widget("table_lookup",  m_pTable_Lookup);
   refGlade->get_widget_derived("combobox_lookup_relationship",  m_pCombo_LookupRelationship);
   refGlade->get_widget_derived("combobox_lookup_field",  m_pCombo_LookupField);
 
-  refGlade->get_widget("checkbutton_calculate",  m_pCheck_Calculate);
+  refGlade->get_widget("radiobutton_calculate",  m_pRadio_Calculate);
   refGlade->get_widget("alignment_calculate",  m_pAlignment_Calculate);
   refGlade->get_widget("textview_calculate",  m_pTextView_Calculation);
   refGlade->get_widget("button_edit_calculation",  m_pButton_EditCalculation);
@@ -57,7 +64,8 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
   m_pCombo_LookupRelationship->signal_changed().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_combo_lookup_relationship_changed) );
   m_pCheck_Lookup->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_check_lookup_toggled) );
 
-  m_pCheck_Calculate->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_check_calculate_toggled) );
+  m_pRadio_Calculate->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_radio_calculate_toggled) );
+  m_pRadio_UserEntry->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_radio_userentry_toggled) );
   m_pButton_EditCalculation->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_button_edit_calculation) );
 
   //TODO:
@@ -90,7 +98,7 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
 
   on_foreach_connect(*this);
   on_foreach_connect(*m_pBox_DefaultValueSimple);
-  on_foreach_connect(*m_pBox_DefaultValue);
+  on_foreach_connect(*m_pBox_ValueTab);
   on_foreach_connect(*m_box_formatting);
 
   Dialog_Properties::set_modified(false);
@@ -111,7 +119,7 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   m_table_name = table_name;  //Used for lookup combo boxes.
 
   //Set the Widgets from the field info:
-  //const Gnome::Gda::FieldAttributes& fieldInfo = field->get_field_info();
+  //const Glib::RefPtr<Gnome::Gda::Column>& fieldInfo = field->get_field_info();
 
   m_pEntry_Name->set_text(field->get_name());
   m_pCombo_Type->set_field_type( field->get_glom_type() );
@@ -167,7 +175,7 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   if(document)
   {
     const Document_Glom::type_vecRelationships vecRelationships = document->get_relationships(table_name);
-    m_pCombo_LookupRelationship->set_relationships(vecRelationships, table_name, document->get_table_title(table_name));
+    m_pCombo_LookupRelationship->set_relationships(vecRelationships);
   }
 
   sharedptr<Relationship> lookup_relationship;
@@ -185,10 +193,16 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
 
   //Calculation:
   const Glib::ustring calculation = field->get_calculation();
-  m_pCheck_Calculate->set_active(!calculation.empty());
+  if(calculation.empty())
+   m_pRadio_UserEntry->set_active();
+  else
+    m_pRadio_Calculate->set_active();
+
   on_check_lookup_toggled();
 
+   std::cout << "debug: dialog_fielddefinition.c:: m_pTextView_Calculation.gobj() gtype = " << G_OBJECT_TYPE_NAME(m_pTextView_Calculation->gobj()) << std::endl;
   m_pTextView_Calculation->get_buffer()->set_text(calculation);
+  std::cout << "  debug: dialog_fielddefinition.c:: after get_buffer()" << std::endl;
 
   m_pEntry_Title->set_text(field->get_title());
 
@@ -207,20 +221,20 @@ sharedptr<Field> Dialog_FieldDefinition::get_field() const
 
   //Get the field info from the widgets:
 
-  Gnome::Gda::FieldAttributes fieldInfo = field->get_field_info(); //Preserve previous information.
+  Glib::RefPtr<Gnome::Gda::Column> fieldInfo = field->get_field_info(); //Preserve previous information.
 
-  fieldInfo.set_name(m_pEntry_Name->get_text());
+  fieldInfo->set_name(m_pEntry_Name->get_text());
 
-  fieldInfo.set_gdatype( Field::get_gda_type_for_glom_type( m_pCombo_Type->get_field_type() ) );
+  fieldInfo->set_g_type( Field::get_gda_type_for_glom_type( m_pCombo_Type->get_field_type() ) );
 
-  fieldInfo.set_unique_key(m_pCheck_Unique->get_active());
-  fieldInfo.set_primary_key(m_pCheck_PrimaryKey->get_active());
-  fieldInfo.set_auto_increment(m_pCheck_AutoIncrement->get_active());
+  fieldInfo->set_unique_key(m_pCheck_Unique->get_active());
+  fieldInfo->set_primary_key(m_pCheck_PrimaryKey->get_active());
+  fieldInfo->set_auto_increment(m_pCheck_AutoIncrement->get_active());
 
-  if(!fieldInfo.get_auto_increment()) //Ignore default_values for auto_increment fields - it's just some obscure postgres code.
+  if(!fieldInfo->get_auto_increment()) //Ignore default_values for auto_increment fields - it's just some obscure postgres code.
   {
     //Simple default value:
-    fieldInfo.set_default_value( m_pDataWidget_DefaultValueSimple->get_value() );
+    fieldInfo->set_default_value( m_pDataWidget_DefaultValueSimple->get_value() );
   }
 
   //Lookup:
@@ -237,10 +251,10 @@ sharedptr<Field> Dialog_FieldDefinition::get_field() const
 
 
   //Calculation:
-  if(m_pCheck_Calculate)
+  if(m_pRadio_Calculate)
     field->set_calculation(m_pTextView_Calculation->get_buffer()->get_text());
 
-  Gnome::Gda::FieldAttributes field_info_copy = fieldInfo;
+  Glib::RefPtr<Gnome::Gda::Column> field_info_copy = fieldInfo;
 
   field->set_field_info(fieldInfo);
 
@@ -267,7 +281,7 @@ void Dialog_FieldDefinition::on_combo_type_changed()
 }
 
 void Dialog_FieldDefinition::enforce_constraints()
-{  
+{
   if(m_pCheck_PrimaryKey->get_active())
   {
     m_pCheck_Unique->set_active(true); //Primary keys must be unique.
@@ -278,16 +292,19 @@ void Dialog_FieldDefinition::enforce_constraints()
 
   if(m_pCheck_Unique->get_active() || m_pCheck_AutoIncrement->get_active())
   {
-    m_pBox_DefaultValue->set_sensitive(false); //Disable all controls on the Notebook page.
+    m_pBox_ValueTab->set_sensitive(false); //Disable all controls on the Notebook page.
     m_pDataWidget_DefaultValueSimple->set_value( Gnome::Gda::Value() ); //Unique fields cannot have default values. //TODO: People will be surprised when they lose information here. We should probably read the text as "" if the widget is disabled.
   }
   else
   {
-    m_pBox_DefaultValue->set_sensitive(true);
+    m_pBox_ValueTab->set_sensitive(true);
   }
 
-  bool enable_calc = m_pCheck_Calculate->get_active();
+  const bool enable_calc = m_pRadio_Calculate->get_active();
   m_pAlignment_Calculate->set_sensitive(enable_calc);
+
+  const bool enable_userentry = m_pRadio_UserEntry->get_active();
+  m_pAlignment_UserEntry->set_sensitive(enable_userentry);
 }
 
 void Dialog_FieldDefinition::on_check_lookup_toggled()
@@ -299,15 +316,24 @@ void Dialog_FieldDefinition::on_check_lookup_toggled()
   enforce_constraints();
 }
 
-void Dialog_FieldDefinition::on_check_calculate_toggled()
+void Dialog_FieldDefinition::on_radio_calculate_toggled()
 {
-  bool enable = m_pCheck_Calculate->get_active();
+  bool enable = m_pRadio_Calculate->get_active();
   m_pAlignment_Calculate->set_sensitive(enable);
 
   //re-disable it if it was not meant to be enabled:
   enforce_constraints();
 }
 
+void Dialog_FieldDefinition::on_radio_userentry_toggled()
+{
+  bool enable = m_pRadio_UserEntry->get_active();
+  m_pAlignment_UserEntry->set_sensitive(enable);
+
+  //re-disable it if it was not meant to be enabled:
+  enforce_constraints();
+}
+
 
 void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
 {
@@ -353,7 +379,7 @@ void Dialog_FieldDefinition::on_button_edit_calculation()
       m_Field->set_calculation( m_pTextView_Calculation->get_buffer()->get_text() );
       dialog->set_field(m_Field, m_table_name);
       //TODO: dialog.set_transient_for(*get_app_window());
-      int response = dialog->run();
+      int response = Glom::Utils::dialog_run_with_help(dialog, "window_field_calculation");
       if(response == Gtk::RESPONSE_OK)
       {
         m_pTextView_Calculation->get_buffer()->set_text( dialog->get_field()->get_calculation() );
@@ -365,6 +391,7 @@ void Dialog_FieldDefinition::on_button_edit_calculation()
   }
 }
 
+} //namespace Glom
 
 
 
