@@ -21,6 +21,9 @@
 #include "notebook_glom.h"
 #include "application.h"
 
+namespace Glom
+{
+
 Notebook_Glom::Notebook_Glom()
 {
   m_uiPreviousPage = 0;
@@ -51,11 +54,10 @@ void Notebook_Glom::on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageN
   //Remove the help hint for the previous page:
   Gtk::Window* pApp = get_app_window();
 
-  App_Glom* pAppGlom = dynamic_cast<App_Glom*>(pApp);
-  if(pAppGlom)
-  {
-    pAppGlom->statusbar_clear();
-  }
+  //if(pAppGlom)
+  //{
+  //  pAppGlom->statusbar_clear();
+ // }
 
   //m_signal_leave_page.emit(m_uiPreviousPage);
   m_uiPreviousPage = uiPageNumber; //Remember the current page for next time.
@@ -67,9 +69,10 @@ void Notebook_Glom::on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageN
     Box_DB* pBox = dynamic_cast<Box_DB*>(pChild);
     if(pBox)
     {
-      pBox->load_from_document();
+      //pBox->load_from_document();
 
       //Set the default button, if there is one:
+      App_Glom* pAppGlom = dynamic_cast<App_Glom*>(pApp);
       if(pAppGlom)
       {
         Gtk::Widget* default_button = pBox->get_default_button();
@@ -110,6 +113,7 @@ Gtk::Window* Notebook_Glom::get_app_window()
   return dynamic_cast<Gtk::Window*>(get_toplevel());
 }
 
+/*
 void Notebook_Glom::show_hint()
 {
   int iPageCurrent = get_current_page();
@@ -122,6 +126,7 @@ void Notebook_Glom::show_hint()
       pBox->show_hint();
   }
 }
+*/
 
 void Notebook_Glom::do_menu_developer_layout()
 {
@@ -132,3 +137,5 @@ void Notebook_Glom::do_menu_file_print()
 {
   //Override this.
 }
+
+} //namespace Glom
