@@ -25,15 +25,18 @@
 #include "comboglom.h"
 #include "textviewglom.h"
 #include "imageglom.h"
-#include "../data_structure/glomconversions.h"
+#include <glom/libglom/data_structure/glomconversions.h>
 #include "../application.h"
 #include "../mode_data/dialog_choose_field.h"
 #include "dialog_choose_id.h"
 #include "dialog_choose_date.h"
 #include "../layout_item_dialogs/dialog_field_layout.h"
-#include "../utils.h"
+#include <glom/libglom/utils.h>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 /*
 DataWidget::DataWidget(Field::glom_field_type glom_type, const Glib::ustring& title)
 : m_glom_type(glom_type),
@@ -135,7 +138,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
           //set_choices() needs this, for the numeric layout:
           combo->set_layout_item( get_layout_item(), table_name);
 
-          combo->set_choices_with_second( GlomUtils::get_choice_values(field) );
+          combo->set_choices_with_second( Utils::get_choice_values(field) );
         }
       }
       else
@@ -147,7 +150,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     }
     else
     {
-      if(field->get_formatting_used().get_text_format_multiline())
+      if((glom_type == Field::TYPE_TEXT) && (field->get_formatting_used().get_text_format_multiline()))
       {
         TextViewGlom* textview = Gtk::manage(new TextViewGlom(glom_type));
         pFieldWidget = textview;
@@ -161,7 +164,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
       pFieldWidget->set_layout_item( get_layout_item(), table_name); //TODO_Performance: We only need this for the numerical format.
     }
   }
-  
+
   if(pFieldWidget)
   {
     pFieldWidget->signal_edited().connect( sigc::mem_fun(*this, &DataWidget::on_widget_edited)  );
@@ -177,7 +180,20 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     if(glom_type == Field::TYPE_IMAGE) //GtkImage widgets default to no size (invisible) if they are empty.
       m_child->set_size_request(width, width);
     else
-      m_child->set_size_request(width, -1 /* auto */);
+    {
+      int height = -1; //auto.
+      if((glom_type == Field::TYPE_TEXT) && (field->get_formatting_used().get_text_format_multiline()))
+      {
+        int example_width = 0;
+        int example_height = 0;
+        Glib::RefPtr<Pango::Layout> refLayout = create_pango_layout("example"); //TODO: Use different text, according to the current locale, or allow the user to choose an example?
+        refLayout->get_pixel_size(example_width, example_height);
+        if(example_height > 0)
+          height = example_height * field->get_formatting_used().get_text_format_multiline_height_lines();
+      }
+
+      m_child->set_size_request(width, height);
+    }
 
     m_child->show_all();
   }
@@ -263,8 +279,8 @@ void DataWidget::set_value(const Gnome::Gda::Value& value)
     if(checkbutton)
     {
       bool bValue = false;
-      if(!value.is_null() && value.get_value_type() == Gnome::Gda::VALUE_TYPE_BOOLEAN)
-        bValue = value.get_bool();
+      if(!value.is_null() && value.get_value_type() == G_TYPE_BOOLEAN)
+        bValue = value.get_boolean();
 
       checkbutton->set_active( bValue );
     }
@@ -310,11 +326,8 @@ int DataWidget::get_suitable_width(const sharedptr<const LayoutItem_Field>& fiel
   {
     case(Field::TYPE_DATE):
     {
-      Gnome::Gda::Date date = {0, 0, 0};
-      date.day = 31;
-      date.month = 12;
-      date.year = 2000;
-      example_text = GlomConversions::get_text_for_gda_value(field_type, Gnome::Gda::Value(date));
+      Glib::Date date(31, Glib::Date::Month(12), 2000);
+      example_text = Conversions::get_text_for_gda_value(field_type, Gnome::Gda::Value(date));
       break;
     }
     case(Field::TYPE_TIME):
@@ -323,7 +336,7 @@ int DataWidget::get_suitable_width(const sharedptr<const LayoutItem_Field>& fiel
       time.hour = 24;
       time.minute = 59;
       time.second = 59;
-      example_text = GlomConversions::get_text_for_gda_value(field_type, Gnome::Gda::Value(time));
+      example_text = Conversions::get_text_for_gda_value(field_type, Gnome::Gda::Value(time));
       break;
     }
     case(Field::TYPE_NUMERIC):
@@ -687,12 +700,15 @@ void DataWidget::on_button_choose_date()
       dialog->set_transient_for(*get_application());
       dialog->set_date_chosen(get_value());
 
-      const int response = dialog->run();
+      const int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_choose_date");
       dialog->hide();
       if(response == Gtk::RESPONSE_OK)
       {
         //Get the chosen date
-        set_value(dialog->get_date_chosen());
+        const Gnome::Gda::Value value = dialog->get_date_chosen();
+        set_value(value);
+
+        m_signal_edited.emit(value);
       }
 
       delete dialog;
@@ -758,3 +774,5 @@ void DataWidget::on_button_choose_date()
 
   return result;
 }
+
+} //namespace Glom
